==> haskell-random-fu-0.2.7.7-88-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-random-fu.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 random-fu
version:              0.2.7.7
visibility:           public
id:                   random-fu-0.2.7.7-KnKBdXcq6myL8ZyGeULsaa
key:                  random-fu-0.2.7.7-KnKBdXcq6myL8ZyGeULsaa
license:              LicenseRef-PublicDomain
maintainer:           Dominic Steinitz <dominic@steinitz.org>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/mokus0/random-fu
synopsis:             Random number generation
description:
    Random number generation based on modeling random
    variables in two complementary ways: first, by the
    parameters of standard mathematical distributions and,
    second, by an abstract type ('\''RVar'\'') which can be
    composed and manipulated monadically and sampled in
    either monadic or \"pure\" styles.

    The primary purpose of this library is to support
    defining and sampling a wide variety of high quality
    random variables.  Quality is prioritized over speed,
    but performance is an important goal too.

    In my testing, I have found it capable of speed
    comparable to other Haskell libraries, but still
    a fair bit slower than straight C implementations of
    the same algorithms.

category:             Math
abi:                  fbcc684b32f159172300fa66851bc735
exposed:              True
exposed-modules:
    Data.Random Data.Random.Distribution
    Data.Random.Distribution.Bernoulli Data.Random.Distribution.Beta
    Data.Random.Distribution.Binomial
    Data.Random.Distribution.Categorical
    Data.Random.Distribution.ChiSquare
    Data.Random.Distribution.Dirichlet
    Data.Random.Distribution.Exponential Data.Random.Distribution.Gamma
    Data.Random.Distribution.Multinomial
    Data.Random.Distribution.Normal Data.Random.Distribution.Pareto
    Data.Random.Distribution.Poisson Data.Random.Distribution.Rayleigh
    Data.Random.Distribution.Simplex
    Data.Random.Distribution.StretchedExponential
    Data.Random.Distribution.T Data.Random.Distribution.Triangular
    Data.Random.Distribution.Uniform Data.Random.Distribution.Weibull
    Data.Random.Distribution.Ziggurat Data.Random.Internal.Find
    Data.Random.Internal.Fixed Data.Random.Lift Data.Random.List
    Data.Random.RVar Data.Random.Sample Data.Random.Vector

import-dirs:          /usr/lib/ghc-9.0.1/site-local/random-fu-0.2.7.7
library-dirs:         /usr/lib/ghc-9.0.1/site-local/random-fu-0.2.7.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/random-fu-0.2.7.7
hs-libraries:         HSrandom-fu-0.2.7.7-KnKBdXcq6myL8ZyGeULsaa
depends:
    base-4.15.0.0 erf-2.0.0.0-3zMgPptNqkU60SoZmaKCwc
    math-functions-0.3.4.2-Kxgq30uxHawE6GNBSh9t1O
    monad-loops-0.4.3-CoSqVlGqFyAAyK5Lg2m9AJ mtl-2.2.2
    random-1.2.1-8FQ7ZTDXKjB8vKwDPZ78R1
    random-shuffle-0.0.4-6rK9SKJeOAh7LimneXbz2O
    random-source-0.3.0.11-6xayfPXnPoo97XnE4kaWWS
    rvar-0.2.0.6-LXGKlaysB3I3WDHjYzNhpT
    syb-0.7.2.1-JJZ7ElOKhr6qvmtx8wPbK template-haskell-2.17.0.0
    transformers-0.5.6.2 vector-0.12.3.1-7avVqi4S14u4vwRbDqmIKr

haddock-interfaces:   /usr/share/doc/haskell-random-fu/html/random-fu.haddock
haddock-html:         /usr/share/doc/haskell-random-fu/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-random-fu-0.2.7.7-90-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-random-fu.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 random-fu
version:              0.2.7.7
visibility:           public
id:                   random-fu-0.2.7.7-3wQGXzHnJwb4NIBiB0aRhs
key:                  random-fu-0.2.7.7-3wQGXzHnJwb4NIBiB0aRhs
license:              LicenseRef-PublicDomain
maintainer:           Dominic Steinitz <dominic@steinitz.org>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/mokus0/random-fu
synopsis:             Random number generation
description:
    Random number generation based on modeling random
    variables in two complementary ways: first, by the
    parameters of standard mathematical distributions and,
    second, by an abstract type ('\''RVar'\'') which can be
    composed and manipulated monadically and sampled in
    either monadic or \"pure\" styles.

    The primary purpose of this library is to support
    defining and sampling a wide variety of high quality
    random variables.  Quality is prioritized over speed,
    but performance is an important goal too.

    In my testing, I have found it capable of speed
    comparable to other Haskell libraries, but still
    a fair bit slower than straight C implementations of
    the same algorithms.

category:             Math
abi:                  a01e06032e2eb4faafbcf34967d3724b
exposed:              True
exposed-modules:
    Data.Random Data.Random.Distribution
    Data.Random.Distribution.Bernoulli Data.Random.Distribution.Beta
    Data.Random.Distribution.Binomial
    Data.Random.Distribution.Categorical
    Data.Random.Distribution.ChiSquare
    Data.Random.Distribution.Dirichlet
    Data.Random.Distribution.Exponential Data.Random.Distribution.Gamma
    Data.Random.Distribution.Multinomial
    Data.Random.Distribution.Normal Data.Random.Distribution.Pareto
    Data.Random.Distribution.Poisson Data.Random.Distribution.Rayleigh
    Data.Random.Distribution.Simplex
    Data.Random.Distribution.StretchedExponential
    Data.Random.Distribution.T Data.Random.Distribution.Triangular
    Data.Random.Distribution.Uniform Data.Random.Distribution.Weibull
    Data.Random.Distribution.Ziggurat Data.Random.Internal.Find
    Data.Random.Internal.Fixed Data.Random.Lift Data.Random.List
    Data.Random.RVar Data.Random.Sample Data.Random.Vector

import-dirs:          /usr/lib/ghc-9.0.1/site-local/random-fu-0.2.7.7
library-dirs:         /usr/lib/ghc-9.0.1/site-local/random-fu-0.2.7.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/random-fu-0.2.7.7
hs-libraries:         HSrandom-fu-0.2.7.7-3wQGXzHnJwb4NIBiB0aRhs
depends:
    base-4.15.0.0 erf-2.0.0.0-3zMgPptNqkU60SoZmaKCwc
    math-functions-0.3.4.2-CC7340LsgigA2WQ2qnbEzt
    monad-loops-0.4.3-CoSqVlGqFyAAyK5Lg2m9AJ mtl-2.2.2
    random-1.2.1-6YdpqMQvDfG35ZWURseofq
    random-shuffle-0.0.4-8Cp4IwbzTE3IkdpRFeosXO
    random-source-0.3.0.11-GZhdx7ebLP15E64wMcEyw3
    rvar-0.2.0.6-C5UKw3I9BmGBMFvzPaT1Kl
    syb-0.7.2.1-1a6c6zHMv9nII8iZ0MCvXA template-haskell-2.17.0.0
    transformers-0.5.6.2 vector-0.12.3.1-EZShNBWDQ9s3G4ursgcoB7

haddock-interfaces:   /usr/share/doc/haskell-random-fu/html/random-fu.haddock
haddock-html:         /usr/share/doc/haskell-random-fu/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
